@@ -17,8 +17,7 @@ class Job(BaseLabResource):
     def get_dir(self):
         """Abstract method on BaseLabResource"""
         job_id_safe = secure_filename(str(self.id))
-        job_dir = os.path.join(dirs.JOBS_DIR, job_id_safe)
-        os.makedirs(job_dir, exist_ok=True)
+        job_dir = os.path.join(dirs.get_jobs_dir(), job_id_safe)
         return job_dir
 
     def get_log_path(self):
@@ -111,7 +110,7 @@ class Job(BaseLabResource):
         Updates a key-value pair in the job_data JSON object.
         """
         # Fetch current job_data
-        json_data = self._get_json_data()
+        json_data = self.get_json_data()
 
         # If there isn't a job_data property then make one
         if "job_data" not in json_data:
@@ -148,3 +147,81 @@ class Job(BaseLabResource):
         except Exception:
             # Best-effort file logging; ignore file errors to avoid crashing job
             pass
+
+    def set_type(self, job_type: str):
+        """
+        Set the type of this job.
+        """
+        self._update_json_data_field("type", job_type)
+
+    def get_experiment_id(self):
+        """
+        Get the experiment_id of this job.
+        """
+        return self._get_json_data_field("experiment_id")
+
+    def set_error_message(self, error_msg: str):
+        """
+        Set an error message in the job_data.
+        """
+        self.update_job_data_field("error_msg", str(error_msg))
+
+    def update_sweep_progress(self, value):
+        """
+        Update the 'sweep_progress' key in the job_data JSON object.
+        """
+        self.update_job_data_field("sweep_progress", value)
+
+    @classmethod
+    def count_running_jobs(cls):
+        """
+        Count how many jobs are currently running.
+        """
+        count = 0
+        jobs_dir = dirs.get_jobs_dir()
+        if os.path.exists(jobs_dir):
+            for entry in os.listdir(jobs_dir):
+                job_path = os.path.join(jobs_dir, entry)
+                if os.path.isdir(job_path):
+                    try:
+                        job = cls.get(entry)
+                        job_data = job.get_json_data()
+                        if job_data.get("status") == "RUNNING":
+                            count += 1
+                    except Exception:
+                        pass
+        return count
+
+    @classmethod
+    def get_next_queued_job(cls):
+        """
+        Get the next queued job (oldest first based on directory creation time).
+        Returns Job data dict or None if no queued jobs.
+        """
+        queued_jobs = []
+        jobs_dir = dirs.get_jobs_dir()
+        if os.path.exists(jobs_dir):
+            for entry in os.listdir(jobs_dir):
+                job_path = os.path.join(jobs_dir, entry)
+                if os.path.isdir(job_path):
+                    try:
+                        job = cls.get(entry)
+                        job_data = job.get_json_data()
+                        if job_data.get("status") == "QUEUED":
+                            # Use filesystem creation time for sorting
+                            creation_time = os.path.getctime(job_path)
+                            queued_jobs.append((creation_time, job_data))
+                    except Exception:
+                        pass
+        
+        if queued_jobs:
+            # Sort by creation time and return the oldest
+            queued_jobs.sort(key=lambda x: x[0])
+            return queued_jobs[0][1]
+        return None
+
+    def delete(self):
+        """
+        Mark this job as deleted.
+        """
+        self.update_status("DELETED")
\ No newline at end of file
